==> libreoffice_5.4.6.orig-tarballs.tar.xz: gpgme-1.8.0/lang/qt/tests/t-support.h <==
/* t-support.h

    This file is part of qgpgme, the Qt API binding for gpgme
    Copyright (c) 2016 Intevation GmbH

    QGpgME is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    QGpgME is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/
#ifndef T_SUPPORT_H
#define T_SUPPORT_H

#include "interfaces/passphraseprovider.h"
#include <QObject>

namespace GpgME
{
class TestPassphraseProvider : public PassphraseProvider
{
public:
    char *getPassphrase(const char * /*useridHint*/, const char * /*description*/,
                        bool /*previousWasBad*/, bool &/*canceled*/) Q_DECL_OVERRIDE
    {
        return strdup("abc");
    }
};
} // namespace GpgME

void killAgent(const QString &dir = qgetenv("GNUPGHOME"));

class QGpgMETest : public QObject
{
    Q_OBJECT
protected:
    bool copyKeyrings(const QString &from, const QString& to);

public Q_SLOTS:
    void initTestCase();
    void cleanupTestCase();
};

#endif // T_SUPPORT_H

==> libreoffice_6.0.3.orig-tarballs.tar.xz: gpgme-1.9.0/lang/qt/tests/t-support.h <==
/* t-support.h

    This file is part of qgpgme, the Qt API binding for gpgme
    Copyright (c) 2016 Intevation GmbH

    QGpgME is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    QGpgME is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/
#ifndef T_SUPPORT_H
#define T_SUPPORT_H

#include "interfaces/passphraseprovider.h"
#include <QObject>

#include <gpg-error.h>

namespace GpgME
{
class TestPassphraseProvider : public PassphraseProvider
{
public:
    char *getPassphrase(const char * /*useridHint*/, const char * /*description*/,
                        bool /*previousWasBad*/, bool &/*canceled*/) Q_DECL_OVERRIDE
    {
        char *ret;
        gpgrt_asprintf(&ret, "abc");
        return ret;
    }
};
} // namespace GpgME

void killAgent(const QString &dir = qgetenv("GNUPGHOME"));

class QGpgMETest : public QObject
{
    Q_OBJECT
protected:
    bool copyKeyrings(const QString &from, const QString& to);

public Q_SLOTS:
    void initTestCase();
    void cleanupTestCase();
};

/* Timeout, in milliseconds, for use with QSignalSpy to wait on
   signals.  */
#define QSIGNALSPY_TIMEOUT	60000

#endif // T_SUPPORT_H
